# Generated by Django 5.1.5 on 2025-02-07 10:33

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "cesnet_service_path_plugin",
            "0016_remove_segment_note_a_remove_segment_note_b",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="segment",
            name="device_a",
        ),
        migrations.RemoveField(
            model_name="segment",
            name="device_b",
        ),
        migrations.RemoveField(
            model_name="segment",
            name="port_a",
        ),
        migrations.RemoveField(
            model_name="segment",
            name="port_b",
        ),
    ]
