# Generated by Django 5.2.5 on 2025-10-10 11:43

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("cesnet_service_path_plugin", "0028_alter_segmentfinancialinfo_options"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="segment",
            name="provider_segment_contract",
        ),
        migrations.RemoveField(
            model_name="segment",
            name="provider_segment_name",
        ),
    ]
