# Generated by Django 4.2.8 on 2024-05-07 07:33

from django.db import migrations, models
import taggit.managers
import utilities.json


class Migration(migrations.Migration):
    dependencies = [
        ("extras", "0106_bookmark_user_cascade_deletion"),
        ("cesnet_service_path_plugin", "0001_segment"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServicePath",
            fields=[
                (
                    "id",
                    models.BigAutoField(auto_created=True, primary_key=True, serialize=False),
                ),
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                (
                    "custom_field_data",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        encoder=utilities.json.CustomFieldJSONEncoder,
                    ),
                ),
                ("name", models.CharField(max_length=225)),
                ("state", models.CharField(max_length=225)),
                ("kind", models.CharField(max_length=225)),
                (
                    "tags",
                    taggit.managers.TaggableManager(through="extras.TaggedItem", to="extras.Tag"),
                ),
            ],
            options={
                "ordering": ("name", "state", "kind"),
            },
        ),
    ]
