# Generated by Django 5.2.7 on 2025-10-21 09:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("cesnet_service_path_plugin", "0027_segmentfinancialinfo"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="segmentfinancialinfo",
            options={"ordering": ("segment",)},
        ),
    ]
