# Generated by Django 5.2.5 on 2025-09-15 09:13

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cesnet_service_path_plugin", "0025_alter_segment_path_geometry"),
    ]

    operations = [
        migrations.AddField(
            model_name="segment",
            name="segment_type",
            field=models.CharField(default="dark_fiber", max_length=30),
        ),
        migrations.AddField(
            model_name="segment",
            name="type_specific_data",
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
