# Generated by Django 5.0.6 on 2024-07-12 11:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cesnet_service_path_plugin", "0006_remove_servicepath_circuits_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="segment",
            name="comments",
            field=models.TextField(blank=True),
        ),
    ]
